@@ -1049,8 +1049,8 @@ class MainWindow(QtWidgets.QMainWindow):
             if buttonReply == QtWidgets.QMessageBox.Yes:
                 self.close()
                 # package = 'enhancedlabelme==%s'%(str(newversion[0]))
-                package = '--upgrade enhancedlabelme'
-                subprocess.check_call([sys.executable, "-m", "pip", "install", package])
+                package = 'enhancedlabelme'
+                subprocess.check_call([sys.executable, "-m", "pip", "install", "--upgrade", package])
                 sys.exit(self.reload())
         else:
             return QtWidgets.QMessageBox.about(
