@@ -98,7 +98,11 @@ class Shape(object):
         self.points.insert(i, point)
 
     def removePoint(self, i):
-        self.points.pop(i)
+        if(len(self.points) > i):
+            self.points.pop(i)
+            
+    def haveNoPoints(self):
+        return len(self.points) == 0
 
     def isClosed(self):
         return self._closed
@@ -207,6 +211,8 @@ class Shape(object):
             pass
 
     def containsPoint(self, point):
+        if(len(self.points) == 0):
+            return False
         return self.makePath().contains(point)
 
     def getCircleRectFromLine(self, line):
